==> webkit_1.7.5.orig.tar.xz: webkit-1.7.5/Source/WebCore/css/CSSFontFaceRule.h <==
/*
 * (C) 1999-2003 Lars Knoll (knoll@kde.org)
 * (C) 2002-2003 Dirk Mueller (mueller@kde.org)
 * Copyright (C) 2002, 2006, 2008 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef CSSFontFaceRule_h
#define CSSFontFaceRule_h

#include "CSSRule.h"
#include "StylePropertySet.h"
#include <wtf/PassRefPtr.h>
#include <wtf/RefPtr.h>

namespace WebCore {

class CSSFontFaceRule : public CSSRule {
public:
    static PassRefPtr<CSSFontFaceRule> create()
    {
        return adoptRef(new CSSFontFaceRule(0));
    }
    static PassRefPtr<CSSFontFaceRule> create(CSSStyleSheet* parent)
    {
        return adoptRef(new CSSFontFaceRule(parent));
    }

    ~CSSFontFaceRule();

    CSSStyleDeclaration* style() const { return m_style->ensureCSSStyleDeclaration(); }

    String cssText() const;

    StylePropertySet* declaration() const { return m_style.get(); }
    void setDeclaration(PassRefPtr<StylePropertySet> style) { m_style = style; }

    void addSubresourceStyleURLs(ListHashSet<KURL>& urls);

private:
    CSSFontFaceRule(CSSStyleSheet* parent);

    RefPtr<StylePropertySet> m_style;
};

} // namespace WebCore

#endif // CSSFontFaceRule_h

==> webkit-1.8.0.tar.xz: webkit-1.8.0/Source/WebCore/css/CSSFontFaceRule.h <==
/*
 * (C) 1999-2003 Lars Knoll (knoll@kde.org)
 * (C) 2002-2003 Dirk Mueller (mueller@kde.org)
 * Copyright (C) 2002, 2006, 2008 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef CSSFontFaceRule_h
#define CSSFontFaceRule_h

#include "CSSRule.h"
#include "StylePropertySet.h"
#include <wtf/PassRefPtr.h>
#include <wtf/RefPtr.h>

namespace WebCore {

class CSSFontFaceRule : public CSSRule {
public:
    static PassRefPtr<CSSFontFaceRule> create()
    {
        return adoptRef(new CSSFontFaceRule(0));
    }
    static PassRefPtr<CSSFontFaceRule> create(CSSStyleSheet* parent)
    {
        return adoptRef(new CSSFontFaceRule(parent));
    }

    ~CSSFontFaceRule();

    CSSStyleDeclaration* style() const { return m_style->ensureRuleCSSStyleDeclaration(this); }

    String cssText() const;

    StylePropertySet* declaration() const { return m_style.get(); }
    void setDeclaration(PassRefPtr<StylePropertySet> style) { m_style = style; }

    void addSubresourceStyleURLs(ListHashSet<KURL>& urls);

private:
    CSSFontFaceRule(CSSStyleSheet* parent);

    RefPtr<StylePropertySet> m_style;
};

} // namespace WebCore

#endif // CSSFontFaceRule_h
